==> haskell-storable-complex-0.2.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-complex
version: 0.2.2
id: storable-complex-0.2.2-G1JxPegbRDG96DIdCk5scT
key: storable-complex-0.2.2-G1JxPegbRDG96DIdCk5scT
license: BSD3
maintainer: Carter Schonwald <carter.schonwald@gmail.com>
homepage: https://github.com/cartazio/storable-complex
synopsis: Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.
    .
    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.
category: Data
author: Jed Brown <jed@59A2.org>
exposed: True
indefinite: False
exposed-modules:
    Foreign.Storable.Complex
abi: 28d8b0329d44378ac21a1d096e50806b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/storable-complex-0.2.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/storable-complex-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/storable-complex-0.2.2
hs-libraries: HSstorable-complex-0.2.2-G1JxPegbRDG96DIdCk5scT
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock
haddock-html: /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-complex-0.2.2-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-complex
version: 0.2.2
id: storable-complex-0.2.2-7ETJsb6oA1474Zjh98qI1a
key: storable-complex-0.2.2-7ETJsb6oA1474Zjh98qI1a
license: BSD3
maintainer: Carter Schonwald <carter.schonwald@gmail.com>
homepage: https://github.com/cartazio/storable-complex
synopsis: Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.
    .
    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.
category: Data
author: Jed Brown <jed@59A2.org>
exposed: True
indefinite: False
exposed-modules:
    Foreign.Storable.Complex
abi: 4f057691b145d9e3a52fec436669348b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/storable-complex-0.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/storable-complex-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/storable-complex-0.2.2
hs-libraries: HSstorable-complex-0.2.2-7ETJsb6oA1474Zjh98qI1a
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock
haddock-html: /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
